
snakebids
=========
.. image:: https://readthedocs.org/projects/snakebids/badge/?version=latest
  :target: https://snakebids.readthedocs.io/en/latest/?badge=latest
  :alt: Documentation Status

Snakemake + BIDS

This package allows you to build BIDS Apps using Snakemake. It offers:


* Flexible data grabbing with PyBIDS, configurable solely by config file entries
* Helper function for creating BIDS paths inside Snakemake workflows/rules
* Command-line invocation of snakemake workflows with BIDS App compliance
* Configurable argument parsing specified using the Snakemake workflow config
* Execution either as command-line BIDS apps or via snakemake executable

